Welcome to ClientVPS Mirrors

Help for package WaveletGBM
Type: Package
Title: Wavelet Based Gradient Boosting Method
Version: 0.1.0
Author: Dr. Ranjit Kumar Paul [aut, cre], Dr. Md Yeasin [aut]
Maintainer: Dr. Ranjit Kumar Paul <ranjitstat@gmail.com>
Description: Wavelet decomposition method is very useful for modelling noisy time series data. Wavelet decomposition using 'haar' algorithm has been implemented to developed hybrid Wavelet GBM (Gradient Boosting Method) model for time series forecasting using algorithm by Anjoy and Paul (2017) <doi:10.1007/s00521-017-3289-9>.
License: GPL-3
Encoding: UTF-8
Imports: caret, dplyr, caretForecast, Metrics, tseries, stats, wavelets, gbm
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2023-04-06 07:54:16 UTC; YEASIN
Repository: CRAN
Date/Publication: 2023-04-07 08:20:02 UTC

Wavelet Based Gradient Boosting Method

Description

Wavelet Based Gradient Boosting Method

Usage

WaveletGBM(ts, MLag = 12, split_ratio = 0.8, wlevels = 3)

Arguments

ts

Time Series Data

MLag

Maximum Lags

split_ratio

Training and Testing Split

wlevels

Number of Wavelet Levels

Value

References

Examples

library("WaveletGBM")
data<- rnorm(100,100, 10)
WG<-WaveletGBM(ts=data)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.